==> istio-model-v1beta1-6.3.1-sources.jar: io/fabric8/istio/api/security/v1beta1/AuthorizationPolicyExtensionProviderFluentImpl.java <==
package io.fabric8.istio.api.security.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AuthorizationPolicyExtensionProviderFluentImpl<A extends AuthorizationPolicyExtensionProviderFluent<A>> extends BaseFluent<A> implements AuthorizationPolicyExtensionProviderFluent<A>{
  public AuthorizationPolicyExtensionProviderFluentImpl() {
  }
  public AuthorizationPolicyExtensionProviderFluentImpl(AuthorizationPolicyExtensionProvider instance) {
    this.withName(instance.getName()); 
  }
  private String name;
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AuthorizationPolicyExtensionProviderFluentImpl that = (AuthorizationPolicyExtensionProviderFluentImpl) o;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/security/v1beta1/AuthorizationPolicyExtensionProviderFluentImpl.java <==
package io.fabric8.istio.api.security.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AuthorizationPolicyExtensionProviderFluentImpl<A extends AuthorizationPolicyExtensionProviderFluent<A>> extends BaseFluent<A> implements AuthorizationPolicyExtensionProviderFluent<A>{
  public AuthorizationPolicyExtensionProviderFluentImpl() {
  }
  public AuthorizationPolicyExtensionProviderFluentImpl(AuthorizationPolicyExtensionProvider instance) {
    if (instance != null) {
      this.withName(instance.getName());
    }
  }
  private String name;
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AuthorizationPolicyExtensionProviderFluentImpl that = (AuthorizationPolicyExtensionProviderFluentImpl) o;
    if (!java.util.Objects.equals(name, that.name)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name); }
    sb.append("}");
    return sb.toString();
  }
  
}
